.showFirstOnly #flowpanes .page {
    display:none;
}
.showFirstOnly #flowpanes .multipages.page0 {
    display:block;
}
#flowpanes .page.item0 {
    display:block;
}
.flowEnabled #flowpanes .page {
    display:block;
}
#flowtabs {
    display:none;
}

.flowEnabled #flowtabs {
    display:block;
}

.flowEnabled div.page {
    clear:both;
}

.flowEnabled .pageContent {
    float:left;
    position:relative;
}


.flowInitialized div.items,
.flowInitialized div.page,
.flowInitialized div.pageContent {
    height:100%;
    position:relative;
}

.fade div.page,
.flowInitialized.fade div.page {
    position:absolute;
}

div.pageContent {
    margin-right:0px;
    overflow:hidden;
}

.manyItems div.page {
    margin-right:15px;
}

body.narrow .manyItems div.page {
    margin-right:5px;
}

.multipages div.pageContent {
    margin-top:5px;
    margin-right:10px;
}

.flowEnabled .multipages div.pageContent {
    display:none;
}
.flowEnabled .multipages div.pageContent.first {
    display:block;
}
.flowInitialized div.pageContent .item {
    padding:3px;
}

.custom .tileFooter {
    display:block;
    clear:both;
}

.flowInitialized .custom .tileFooter {
    display:block;
    position:absolute;
    bottom:0px;
    right:0px;
    margin-bottom:0;
}

.flowInitialized div.pageContent.first {
    margin-left:0px;
}

.flowInitialized div.pageContent.last {
    margin-right:0px;
}

.flowEnabled.useFlowtabs .googleMapLocation {
    display:none;
}

.flowEnabled.useFlowtabs .googleMapLocation.googleMapActive {
    display:block;
}

.flowEnabled,
.flowEnabled #flow-container {
    position:relative;
}

.flowEnabled #flowpanes_container {
    padding:15px 0 15px 15px;
    clear:both;
}

.showBorder #flowpanes_container {
    border:1px solid #EEEEEE;
    -moz-border-radius:2px;
    -webkit-border-radius:2px;
    border-radius:2px;
    background:white url(flowpanes_background.png) repeat-x left bottom;
}

.flowEnabled #flowpanes {
    position:relative;
    overflow:hidden;
    clear:both;
}

.flowEnabled.backnext_enabled #flowpanes_container {
    margin:0 20px;
}

/* override single pane */
.flowEnabled #flowpanes div.content_item,
.flowEnabled #flowpanes div.collage-item,
.flowEnabled #flowpanes div.page {
    float:left !important;
    clear:none !important;
    display:block;
    width:100%;
}

/* our additional wrapper element for the items */
.flowEnabled #flowpanes .items {
    width:20000em;
    position:absolute;
    clear:both;
    margin:0;
    padding:0;
}

.flowEnabled #flowpanes .less,
.flowEnabled #flowpanes .less a {
    color:#999 !important;
}

.flowEnabled div.title #flowtabs ul,
.flowEnabled div.description #flowtabs ul  {
    float:left;
    margin:0px 15px;
}

.flowEnabled div.title.backnext_enabled #flowtabs ul,
.flowEnabled div.description.backnext_enabled #flowtabs ul  {
    margin:0px 30px;
}

.flowEnabled #flowtabs li {
    display:block;
    float:left;
    list-style-type:none;
    margin:0 5px 0 0;
}

.flowEnabled div.title #flowtabs li,
.flowEnabled div.description #flowtabs li {
    margin:0 5px 0 0;
}

#flowtabs li a,
div.flowEnabled.title #flowtabs.top li a,
div.flowEnabled.description #flowtabs.top li a {
    display:block;
    border-left:1px solid #EEEEEE;
    border-right:1px solid #EEEEEE;
    border-top:1px solid #EEEEEE;
    padding:3px 6px;
    -moz-border-radius-topleft:2px;
    -moz-border-radius-topright:2px;
    -webkit-border-top-left-radius:2px;
    -webkit-border-top-right-radius:2px;
    border-top-left-radius:2px;
    border-top-right-radius:2px;
    border-bottom:none;
}

div.flowEnabled.title #flowtabs.bottom li a,
div.flowEnabled.description #flowtabs.bottom li a {
    display:block;
    border-left:1px solid #EEEEEE;
    border-right:1px solid #EEEEEE;
    border-bottom:1px solid #EEEEEE;
    padding:3px 6px;
    -moz-border-radius-bottomleft:2px;
    -moz-border-radius-bottomright:2px;
    -webkit-border-bottom-left-radius:2px;
    -webkit-border-bottom-right-radius:2px;
    border-bottom-left-radius:2px;
    border-bottom-right-radius:2px;
}

div.flowEnabled.slidetabs #flowtabs {
    float:left;
    margin-left:50%;
    clear:both;
}

div.flowEnabled.slidetabs #flowtabs ul  {
    float:left;
    margin:0 0 0 -50%;
}

div.flowEnabled.slidetabs #flowtabs li {
    margin:0;
}

div.flowEnabled.slidetabs #flowtabs li a {
    width:8px;
    height:8px;
    float:left;
    margin:3px;
    background:url(++resource++solgemaflowview.resources/navigator.png) 0 0 no-repeat;
    display:block;
    font-size:1px;
    border:none;
    padding:0;	
}

div.flowEnabled.slidetabs #flowtabs li a:hover {
	background-position:0 -8px;      
}

div.flowEnabled.slidetabs #flowtabs li a.current {
	background-position:0 -16px;     
} 

.flowEnabled #flowtabs li a.current { 
    background:#AAAAAA none scroll repeat-x bottom left;
    color: #000000;
}

#flow-container .forward,
#flow-container .backward {
    display:none;
}
#flow-container .flowEnabled .forward,
#flow-container .flowEnabled .backward {
    display:block;
}
/* prev and next buttons */
.flowEnabled .forward,
.flowEnabled .backward {
    margin-top:-9px;
    display:block;
    width:18px;
    height:18px;
    cursor:pointer;
    font-size:1px;
    text-indent:-9999em;
    position:absolute;
    top:50%;
    border:none;
}

.flowEnabled .backward {
    background:transparent url(++resource++solgemaflowview.resources/left.png) no-repeat;
    left:0;
}

.flowEnabled .forward {
    background:transparent url(++resource++solgemaflowview.resources/right.png) no-repeat;
    right:0;
}

/* next */
.flowEnabled .forward:hover { background-position:0px -18px; }
.flowEnabled .forward:active { background-position:0px -18px; } 


/* prev */
.flowEnabled .backward:hover { background-position:0px -18px; }
.flowEnabled .backward:active { background-position:0px -18px; }

/* disabled navigational button. is not needed when tabs are configured with rotate: true */
.flowEnabled .disabled {
	visibility:hidden !important;		
}
.banner_item {
    background-size:cover;
    position:relative;
    background-position:center;
    height:100%;
}
.banner_item .banner_content{
    position:absolute;
    right:20%;
    top:10%;
    background-color:rgba(255,255,255,0.8);
    padding:15px;
    min-height: 50%;
    min-width:25%;
    max-width:40%;
    overflow:hidden;
    width:40%
}
body.mini .banner_item .banner_content{
    position:relative;
    margin:auto;
    max-width:70%;
    right:initial;
}
#flow-container .folder_listing {
    margin:0;
}

